@@ -49,6 +49,7 @@
 #include "ardour/session_configuration.h"
 #include "ardour/tempo.h"
 #include "ardour/vca.h"
+#include "ardour/well_known_enum.h"
 
 #include "faderport8.h"
 
@@ -106,26 +107,36 @@ FaderPort8::probe (std::string& i, std::string& o)
 	AudioEngine::instance()->get_ports ("", DataType::MIDI, PortFlags (IsOutput|IsTerminal), midi_inputs);
 	AudioEngine::instance()->get_ports ("", DataType::MIDI, PortFlags (IsInput|IsTerminal), midi_outputs);
 
-	auto has_fp8 = [](string const& s) {
-		std::string pn = AudioEngine::instance()->get_hardware_port_name_by_name (s);
+	if (midi_outputs.size () == 0)
+		DEBUG_TRACE (DEBUG::FaderPort8, "prope got no output midi ports at all - perhaps an audio backend problem?\n");
+	// midi_inputs will never be empty - there is always at least x-virtual-keyboard
+
+	const string needle =
 #ifdef FADERPORT16
-		return pn.find ("PreSonus FP16 Port 1") != string::npos;
+	    "PreSonus FP16 Port 1"
 #elif defined FADERPORT2
-		return pn.find ("PreSonus FP2") != string::npos;
+	    "PreSonus FP2"
 #else
-		return pn.find ("PreSonus FP8") != string::npos;
+	    "PreSonus FP8"
 #endif
+	    ;
+
+	auto has_fp8 = [&needle] (string const& s) {
+		std::string pn = AudioEngine::instance ()->get_hardware_port_name_by_name (s);
+		return pn.find (needle) != string::npos;
 	};
 
 	auto pi = std::find_if (midi_inputs.begin (), midi_inputs.end (), has_fp8);
 	auto po = std::find_if (midi_outputs.begin (), midi_outputs.end (), has_fp8);
 
 	if (pi == midi_inputs.end () || po == midi_outputs.end ()) {
+		DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("prope did not find the '%1' midi ports\n", needle));
 		return false;
 	}
 
 	i = *pi;
 	o = *po;
+	DEBUG_TRACE (DEBUG::FaderPort8, string_compose ("prope found midi ports '%1' and '%2'\n", i, o));
 	return true;
 }
 
@@ -243,8 +254,6 @@ FaderPort8::~FaderPort8 ()
 		AudioEngine::instance()->unregister_port (_output_port);
 		_output_port.reset ();
 	}
-
-	tear_down_gui ();
 }
 
 /* ****************************************************************************
@@ -265,6 +274,7 @@ FaderPort8::do_request (FaderPort8Request* req)
 void
 FaderPort8::stop ()
 {
+	tear_down_gui ();
 	DEBUG_TRACE (DEBUG::FaderPort8, "BaseUI::quit ()\n");
 	BaseUI::quit ();
 	close (); // drop references, disconnect from session signals
@@ -273,8 +283,6 @@ FaderPort8::stop ()
 void
 FaderPort8::thread_init ()
 {
-	pthread_set_name (event_loop_name().c_str());
-
 	PBD::notify_event_loops_about_thread_creation (pthread_self(), event_loop_name(), 2048);
 	ARDOUR::SessionEvent::create_per_thread_pool (event_loop_name(), 128);
 
@@ -968,6 +976,7 @@ FaderPort8::filter_stripables (StripableList& strips) const
 
 	bool allow_master = false;
 	bool allow_monitor = false;
+	bool allow_surround = false;
 
 	switch (_ctrls.mix_mode ()) {
 		case MixAudio:
@@ -987,11 +996,13 @@ FaderPort8::filter_stripables (StripableList& strips) const
 			break;
 		case MixUser:
 			allow_master = true;
+			allow_surround = true;
 			flt = &flt_selected;
 			break;
 		case MixOutputs:
 			allow_master = true;
 			allow_monitor = true;
+			allow_surround = true;
 			flt = &flt_mains;
 			break;
 		case MixInputs:
@@ -1005,6 +1016,7 @@ FaderPort8::filter_stripables (StripableList& strips) const
 			/* fallthrough */
 		case MixAll:
 			allow_master = true;
+			allow_surround = true;
 			flt = &flt_all;
 			break;
 	}
@@ -1018,6 +1030,7 @@ FaderPort8::filter_stripables (StripableList& strips) const
 
 		if (!allow_master  && (*s)->is_master ()) { continue; }
 		if (!allow_monitor && (*s)->is_monitor ()) { continue; }
+		if (!allow_surround && (*s)->is_surround_master ()) { continue; }
 
 		if ((*flt)(*s)) {
 			strips.push_back (*s);
@@ -1330,49 +1343,45 @@ FaderPort8::build_well_known_processor_ctrls (std::shared_ptr<Stripable> s, int
 			{ /* EQ */
 				int cnt = s->eq_band_cnt();
 
-#ifdef MIXBUS32C
-				PUSH_BACK_NON_NULL ("Flt In", s->filter_enable_controllable (true)); // both HP/LP
-				PUSH_BACK_NON_NULL ("HP Freq", s->filter_freq_controllable (true));
-				PUSH_BACK_NON_NULL ("LP Freq", s->filter_freq_controllable (false));
-				PUSH_BACK_NON_NULL ("EQ In", s->eq_enable_controllable ());
-#elif defined (MIXBUS)
-				PUSH_BACK_NON_NULL ("EQ In", s->eq_enable_controllable ());
-				PUSH_BACK_NON_NULL ("HP Freq", s->filter_freq_controllable (true));
+#ifdef MIXBUS
+				PUSH_BACK_NON_NULL ("Flt In", s->mapped_control (HPF_Enable)); // both HP/LP
+				PUSH_BACK_NON_NULL ("HP Freq", s->mapped_control (HPF_Freq));
+				PUSH_BACK_NON_NULL ("LP Freq", s->mapped_control (LPF_Freq));
+				PUSH_BACK_NON_NULL ("EQ In", s->mapped_control (EQ_Enable));
 #endif
 
 				for (int band = 0; band < cnt; ++band) {
 					std::string bn = s->eq_band_name (band);
-					PUSH_BACK_NON_NULL (string_compose ("Gain %1", bn), s->eq_gain_controllable (band));
-					PUSH_BACK_NON_NULL (string_compose ("Freq %1", bn), s->eq_freq_controllable (band));
-					PUSH_BACK_NON_NULL (string_compose ("Band %1", bn), s->eq_q_controllable (band));
-					PUSH_BACK_NON_NULL (string_compose ("Shape %1", bn), s->eq_shape_controllable (band));
+					PUSH_BACK_NON_NULL (string_compose ("Gain %1", bn), s->mapped_control (EQ_BandGain, band));
+					PUSH_BACK_NON_NULL (string_compose ("Freq %1", bn), s->mapped_control (EQ_BandFreq, band));
+					PUSH_BACK_NON_NULL (string_compose ("Band %1", bn), s->mapped_control (EQ_BandQ, band));
+					PUSH_BACK_NON_NULL (string_compose ("Shape %1", bn), s->mapped_control (EQ_BandShape, band));
 				}
 			}
 			break;
 		case 2:
-			PUSH_BACK_NON_NULL ("Comp In", s->comp_enable_controllable ());
-			PUSH_BACK_NON_NULL ("Threshold", s->comp_threshold_controllable ());
-			PUSH_BACK_NON_NULL ("Makeup", s->comp_makeup_controllable ());
-			PUSH_BACK_NON_NULL ("Mode", s->comp_mode_controllable ());
-			PUSH_BACK_NON_NULL ("Speed", s->comp_speed_controllable ());
-			PUSH_BACK_NON_NULL ("Ratio", s->comp_ratio_controllable ());
-			PUSH_BACK_NON_NULL ("Attack", s->comp_attack_controllable ());
-			PUSH_BACK_NON_NULL ("Release", s->comp_release_controllable ());
-			PUSH_BACK_NON_NULL ("Emphasis", s->comp_key_filter_freq_controllable ());
+			PUSH_BACK_NON_NULL ("Comp In", s->mapped_control (Comp_Enable));
+			PUSH_BACK_NON_NULL ("Threshold", s->mapped_control (Comp_Threshold));
+			PUSH_BACK_NON_NULL ("Makeup", s->mapped_control (Comp_Makeup));
+			PUSH_BACK_NON_NULL ("Mode", s->mapped_control (Comp_Mode));
+			PUSH_BACK_NON_NULL ("Ratio", s->mapped_control (Comp_Ratio));
+			PUSH_BACK_NON_NULL ("Attack", s->mapped_control (Comp_Attack));
+			PUSH_BACK_NON_NULL ("Release", s->mapped_control (Comp_Release));
+			PUSH_BACK_NON_NULL ("Emphasis", s->mapped_control (Comp_KeyFilterFreq));
 			break;
 		case 3:
-			PUSH_BACK_NON_NULL ("Gate In", s->gate_enable_controllable ());
-			PUSH_BACK_NON_NULL ("Exp", s->gate_mode_controllable ());
-			PUSH_BACK_NON_NULL ("Threshold", s->gate_threshold_controllable ());
-			PUSH_BACK_NON_NULL ("Depth", s->gate_depth_controllable ());
-			PUSH_BACK_NON_NULL ("Attack", s->gate_attack_controllable ());
-			PUSH_BACK_NON_NULL ("Release", s->gate_release_controllable ());
-			PUSH_BACK_NON_NULL ("Exp Ratio", s->gate_ratio_controllable ());
-			PUSH_BACK_NON_NULL ("Exp Knee", s->gate_knee_controllable ());
-			PUSH_BACK_NON_NULL ("Gate Hyst", s->gate_hysteresis_controllable ());
-			PUSH_BACK_NON_NULL ("Gate Hold", s->gate_hold_controllable ());
-			PUSH_BACK_NON_NULL ("SC Enable", s->gate_key_filter_enable_controllable ());
-			PUSH_BACK_NON_NULL ("SC Freq", s->gate_key_filter_freq_controllable ());
+			PUSH_BACK_NON_NULL ("Gate In", s->mapped_control (Gate_Enable));
+			PUSH_BACK_NON_NULL ("Exp", s->mapped_control (Gate_Mode));
+			PUSH_BACK_NON_NULL ("Threshold", s->mapped_control (Gate_Threshold));
+			PUSH_BACK_NON_NULL ("Depth", s->mapped_control (Gate_Depth));
+			PUSH_BACK_NON_NULL ("Attack", s->mapped_control (Gate_Attack));
+			PUSH_BACK_NON_NULL ("Release", s->mapped_control (Gate_Release));
+			PUSH_BACK_NON_NULL ("Exp Ratio", s->mapped_control (Gate_Ratio));
+			PUSH_BACK_NON_NULL ("Exp Knee", s->mapped_control (Gate_Knee));
+			PUSH_BACK_NON_NULL ("Gate Hyst", s->mapped_control (Gate_Hysteresis));
+			PUSH_BACK_NON_NULL ("Gate Hold", s->mapped_control (Gate_Hold));
+			PUSH_BACK_NON_NULL ("SC Enable", s->mapped_control (Gate_KeyFilterEnable));
+			PUSH_BACK_NON_NULL ("SC Freq", s->mapped_control (Gate_KeyFilterFreq));
 			break;
 		default:
 			assert (0);
@@ -1421,6 +1430,9 @@ FaderPort8::select_plugin (int num)
 		std::shared_ptr<Processor> proc;
 		std::shared_ptr<PluginInsert> pi;
 		for (uint32_t i = 0; 0 != (proc = r->nth_plugin (i)); ++i) {
+			if (!proc->display_to_user ()) {
+				continue;
+			}
 			switch (std::dynamic_pointer_cast<PluginInsert> (proc)->channelstrip ()) {
 				case Processor::MBComp:
 					if (num == -2) {
@@ -1454,6 +1466,8 @@ FaderPort8::select_plugin (int num)
 		plugin->PresetLoaded.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
 		plugin->PresetDirty.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::preset_changed, this), this);
 
+		r->MappedControlsChanged.connect (processor_connections, MISSING_INVALIDATOR, boost::bind (&FaderPort8::stripable_selection_changed, this), this);
+
 		if (_auto_pluginui) {
 			pi->ShowUI (); /* EMIT SIGNAL */
 		}
@@ -1601,11 +1615,11 @@ FaderPort8::spill_plugins ()
 		--spillwidth;
 		have_well_known_eq = true;
 	}
-	if (r->comp_enable_controllable ()) {
+	if (r->mapped_control (Comp_Enable)) {
 		--spillwidth;
 		have_well_known_comp = true;
 	}
-	if (r->gate_enable_controllable ()) {
+	if (r->mapped_control (Gate_Enable)) {
 		--spillwidth;
 		have_well_known_gate = true;
 	}
